@@ -7,7 +7,7 @@ our @ISA = 'Regexp';
 
 BEGIN
 {
-    $VERSION = '0.02';
+    $VERSION = '0.03';
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -34,8 +34,8 @@ re::engine::POSIX - POSIX (IEEE Std 1003.1-2001) regular expressions
 
     use re::engine::POSIX;
 
-    if ("I like Spoo" =~ /like \(.*\)/) {
-        print "Yay $1\n";
+    if ("mooh!" =~ /\([mo]*\)/) {
+        say $1; # "moo"
     }
 
 =head1 DESCRIPTION
@@ -43,31 +43,27 @@ re::engine::POSIX - POSIX (IEEE Std 1003.1-2001) regular expressions
 Replaces perl's regexes in a given lexical scope with the system's
 POSIX regular expression engine.
 
-=head1 Flags
+=head1 Modifiers
 
-POSIX regexes (unlike Perl's) behave as if the C<//s> flag were on by
-default, this can be turned off by specifying the B<REG_NEWLINE> flag
-to B<regcomp> via C<//m>.
+POSIX regexes (unlike Perl's) behave as if the C<//s> modifier were on
+by default, this can be turned off by specifying the B<REG_NEWLINE>
+flag to B<regcomp> via C<//m>.
 
 The other valid flags are C<x> and C<i> which turn on B<REG_EXTENDED>
 and B<REG_ICASE> respectively.
 
-It is not possible to specify the B<REG_NOTBOL> and flags to
-B<REG_NOTEOL> as this does not fit within the Perl syntax.
+It is not possible to specify the B<REG_NOTBOL> and B<REG_NOTEOL>
+flags as they do not fit within the Perl syntax.
 
 =head1 DIAGNOSTICS
 
 Error messages from from B<regerror> will be propagated on invalid
 patterns.
 
-=head1 BUGS
-
-C<//g> will make perl do naughty things, fix. 
-
 =head1 CAVEATS
 
-Does not (yet?) ship with a fallback POSIX regexp implementation on
-systems that don't have one.
+Does not ship with its own regexp implementation so it'll fail on
+non-POSIX systems.
 
 =head1 AUTHOR
 
